import SignalTracker, {ShellWindowTracker} from 'gnome-shell-signal-tracker';

const Meta = imports.gi.Meta;

/**
 * Class that adds a margin around new windows.
 */
export default class WindowCentering {

  /**
   * @param {Number} margin the amount of screen width and height to use as
   * margin.
   */
  constructor(margin=0.25) {
    this.margin = margin;
    this.signals = new SignalTracker();
    this.windows = new ShellWindowTracker(this.signals);
  }

  /**
   * Centers a window.
   *
   * @param {gi.Meta.Window} win the window to center.
   */
  center(win) {
    if (!win.resizeable)
      return;
    const mn = window.global.screen.get_current_monitor();
    const {x, y, width, height} = win.get_workspace().get_work_area_for_monitor(mn);
    win.move_resize_frame(false, x + this.margin * width, y + this.margin * height,
        width * 2 * this.margin, height * 2 * this.margin);
  }

  /**
   * Enables centering all windows.
   */
  enable() {
    this.windows.onEvery(win => this.center(win));
  }

  /**
   * Disables centering all windows.
   */
  disable() {
    this.signals.clean();
  }
}
